@@ -38,10 +38,13 @@
 #define KDE_ROOT_PATH "/"
 #endif
 
-QT_BEGIN_NAMESPACE
-// Avoid QHash randomization so that the order of the devicees is stable
-extern Q_CORE_EXPORT QBasicAtomicInt qt_qhash_seed; // from qhash.cpp
-QT_END_NAMESPACE
+// Avoid QHash randomization so that the order of the devices is stable
+static void seedInit()
+{
+    qputenv("QT_HASH_SEED", "0");
+    qputenv("QT_NO_CPU_FEATURE", "sse4.2");
+}
+Q_CONSTRUCTOR_FUNCTION(seedInit)
 
 class KFilePlacesModelTest : public QObject
 {
@@ -52,8 +55,8 @@ private Q_SLOTS:
     void cleanupTestCase();
 
     void testInitialState();
-    void testReparse();
     void testInitialList();
+    void testReparse();
     void testInternalBookmarksHaveIds();
     void testHiding();
     void testMove();
@@ -75,20 +78,18 @@ private:
     QMap<QString, QDBusInterface *> m_interfacesMap;
 };
 
+static QString bookmarksFile()
+{
+    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/user-places.xbel";
+}
+
 void KFilePlacesModelTest::initTestCase()
 {
-    // Make sure we always use 0 as seed
-    qt_qhash_seed.fetchAndStoreRelaxed(0);
+    qputenv("KDE_FORK_SLAVES", "yes"); // to avoid a runtime dependency on klauncher
+    QStandardPaths::setTestModeEnabled(true);
 
     // Ensure we'll have a clean bookmark file to start
-    const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/kfileplaces/bookmarks.xml";
-    QFile f(file);
-    f.remove();
-
-    // Erase the shared bookmarks file also
-    const QString sharedBookmarksFile = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/user-places.xbel";
-    QFile f2(sharedBookmarksFile);
-    f2.remove();
+    QFile::remove(bookmarksFile());
 
     qRegisterMetaType<QModelIndex>();
     const QString fakeHw = QFINDTESTDATA("fakecomputer.xml");
@@ -103,6 +104,7 @@ void KFilePlacesModelTest::cleanupTestCase()
     delete m_places;
     delete m_places2;
     qDeleteAll(m_interfacesMap);
+    QFile::remove(bookmarksFile());
 }
 
 QStringList KFilePlacesModelTest::placesUrls() const
@@ -140,7 +142,7 @@ QStringList KFilePlacesModelTest::placesUrls() const
 
 QDBusInterface *KFilePlacesModelTest::fakeManager()
 {
-    return fakeDevice("/org/kde/solid/fakehw");
+    return fakeDevice(QStringLiteral("/org/kde/solid/fakehw"));
 }
 
 QDBusInterface *KFilePlacesModelTest::fakeDevice(const QString &udi)
@@ -157,17 +159,20 @@ QDBusInterface *KFilePlacesModelTest::fakeDevice(const QString &udi)
 
 void KFilePlacesModelTest::testInitialState()
 {
-    QCOMPARE(m_places->rowCount(), 4);
+    QCOMPARE(m_places->rowCount(), 4); // when the xbel file is empty, KFilePlacesModel fills it with 4 default items
     QCoreApplication::processEvents(); // Devices have a delayed loading
     QCOMPARE(m_places->rowCount(), 9);
 }
 
+static const QStringList initialListOfUrls()
+{
+    return QStringList() << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+                         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
+}
+
 void KFilePlacesModelTest::testInitialList()
 {
-    QStringList urls;
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
-
+    const QStringList urls = initialListOfUrls();
     CHECK_PLACES_URLS(urls);
 }
 
@@ -177,18 +182,16 @@ void KFilePlacesModelTest::testReparse()
 
     // add item
 
-    m_places->addPlace("foo", QUrl::fromLocalFile("/foo"),
+    m_places->addPlace(QStringLiteral("foo"), QUrl::fromLocalFile(QStringLiteral("/foo")),
                        QString(), QString());
 
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom" << "/foo";
-
+    urls = initialListOfUrls();
+    urls << QStringLiteral("/foo");
     CHECK_PLACES_URLS(urls);
 
     // reparse the bookmark file
 
-    const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kfileplaces/bookmarks.xml";
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
+    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
 
     bookmarkManager->notifyCompleteChange(QString());
 
@@ -200,26 +203,21 @@ void KFilePlacesModelTest::testReparse()
 
     m_places->removePlace(m_places->index(9, 0));
 
-    urls.clear();
-
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
-
+    urls = initialListOfUrls();
     CHECK_PLACES_URLS(urls);
 }
 
 void KFilePlacesModelTest::testInternalBookmarksHaveIds()
 {
-    const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kfileplaces/bookmarks.xml";
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
+    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
     KBookmarkGroup root = bookmarkManager->root();
 
     // Verify every entry has an id or an udi
     KBookmark bookmark = root.first();
     while (!bookmark.isNull()) {
-        QVERIFY(!bookmark.metaDataItem("ID").isEmpty() || !bookmark.metaDataItem("UDI").isEmpty());
+        QVERIFY(!bookmark.metaDataItem(QStringLiteral("ID")).isEmpty() || !bookmark.metaDataItem(QStringLiteral("UDI")).isEmpty());
         // It's mutualy exclusive though
-        QVERIFY(bookmark.metaDataItem("ID").isEmpty() || bookmark.metaDataItem("UDI").isEmpty());
+        QVERIFY(bookmark.metaDataItem(QStringLiteral("ID")).isEmpty() || bookmark.metaDataItem(QStringLiteral("UDI")).isEmpty());
 
         bookmark = root.next(bookmark);
     }
@@ -230,22 +228,22 @@ void KFilePlacesModelTest::testInternalBookmarksHaveIds()
     // It induces a small race condition which means several ids will be
     // successively set on the same bookmark but no big deal since it won't
     // break the system
-    KBookmark foo = root.addBookmark("Foo", QUrl("file:/foo"), "red-folder");
-    QCOMPARE(foo.text(), QString("Foo"));
-    QVERIFY(foo.metaDataItem("ID").isEmpty());
+    KBookmark foo = root.addBookmark(QStringLiteral("Foo"), QUrl(QStringLiteral("file:/foo")), QStringLiteral("red-folder"));
+    QCOMPARE(foo.text(), QStringLiteral("Foo"));
+    QVERIFY(foo.metaDataItem(QStringLiteral("ID")).isEmpty());
     bookmarkManager->emitChanged(root);
-    QCOMPARE(foo.text(), QString("Foo"));
-    QVERIFY(!foo.metaDataItem("ID").isEmpty());
+    QCOMPARE(foo.text(), QStringLiteral("Foo"));
+    QVERIFY(!foo.metaDataItem(QStringLiteral("ID")).isEmpty());
 
     // Verify that all the ids are different
     bookmark = root.first();
     QSet<QString> ids;
     while (!bookmark.isNull()) {
         QString id;
-        if (!bookmark.metaDataItem("UDI").isEmpty()) {
-            id = bookmark.metaDataItem("UDI");
+        if (!bookmark.metaDataItem(QStringLiteral("UDI")).isEmpty()) {
+            id = bookmark.metaDataItem(QStringLiteral("UDI"));
         } else {
-            id = bookmark.metaDataItem("ID");
+            id = bookmark.metaDataItem(QStringLiteral("ID"));
         }
 
         QVERIFY2(!ids.contains(id), "Duplicated ID found!");
@@ -280,8 +278,8 @@ void KFilePlacesModelTest::testHiding()
     QVERIFY(!m_places->data(b, KFilePlacesModel::HiddenRole).toBool());
     QCOMPARE(spy.count(), 1);
     args = spy.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), a);
-    QCOMPARE(args.at(1).value<QModelIndex>(), a);
+    QCOMPARE(args.at(0).toModelIndex(), a);
+    QCOMPARE(args.at(1).toModelIndex(), a);
 
     m_places->setPlaceHidden(b, true);
     QVERIFY(m_places->isHidden(a));
@@ -290,8 +288,8 @@ void KFilePlacesModelTest::testHiding()
     QVERIFY(m_places->data(b, KFilePlacesModel::HiddenRole).toBool());
     QCOMPARE(spy.count(), 1);
     args = spy.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), b);
-    QCOMPARE(args.at(1).value<QModelIndex>(), b);
+    QCOMPARE(args.at(0).toModelIndex(), b);
+    QCOMPARE(args.at(1).toModelIndex(), b);
 
     m_places->setPlaceHidden(a, false);
     m_places->setPlaceHidden(b, false);
@@ -301,11 +299,11 @@ void KFilePlacesModelTest::testHiding()
     QVERIFY(!m_places->data(b, KFilePlacesModel::HiddenRole).toBool());
     QCOMPARE(spy.count(), 2);
     args = spy.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), a);
-    QCOMPARE(args.at(1).value<QModelIndex>(), a);
+    QCOMPARE(args.at(0).toModelIndex(), a);
+    QCOMPARE(args.at(1).toModelIndex(), a);
     args = spy.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), b);
-    QCOMPARE(args.at(1).value<QModelIndex>(), b);
+    QCOMPARE(args.at(0).toModelIndex(), b);
+    QCOMPARE(args.at(1).toModelIndex(), b);
 }
 
 void KFilePlacesModelTest::testMove()
@@ -314,8 +312,7 @@ void KFilePlacesModelTest::testMove()
     QSignalSpy spy_inserted(m_places, SIGNAL(rowsInserted(QModelIndex,int,int)));
     QSignalSpy spy_removed(m_places, SIGNAL(rowsRemoved(QModelIndex,int,int)));
 
-    const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kfileplaces/bookmarks.xml";
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
+    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark trash = m_places->bookmarkForIndex(m_places->index(3, 0));
     KBookmark before_trash = m_places->bookmarkForIndex(m_places->index(2, 0));
@@ -329,18 +326,18 @@ void KFilePlacesModelTest::testMove()
     bookmarkManager->emitChanged(root);
 
     QStringList urls;
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom" << "trash:/";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH)
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign") << QStringLiteral("trash:/");
 
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 8);
     QCOMPARE(args.at(2).toInt(), 8);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
 
@@ -349,18 +346,18 @@ void KFilePlacesModelTest::testMove()
     bookmarkManager->emitChanged(root);
 
     urls.clear();
-    urls << "trash:/" << QDir::homePath() << "remote:/" << KDE_ROOT_PATH
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QStringLiteral("trash:/") << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH)
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
 
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 0);
     QCOMPARE(args.at(2).toInt(), 0);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 9);
     QCOMPARE(args.at(2).toInt(), 9);
 
@@ -368,17 +365,17 @@ void KFilePlacesModelTest::testMove()
     root.moveBookmark(trash, before_trash);
     bookmarkManager->emitChanged(root);
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 0);
     QCOMPARE(args.at(2).toInt(), 0);
 }
@@ -400,17 +397,17 @@ void KFilePlacesModelTest::testDragAndDrop()
     QVERIFY(m_places->dropMimeData(mimeData, Qt::MoveAction, -1, 0, QModelIndex()));
 
     QStringList urls;
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom" << "trash:/";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH)
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign") << QStringLiteral("trash:/");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
     QCOMPARE(spy_moved.count(), 1);
     args = spy_moved.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
-    QCOMPARE(args.at(3).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(3).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(4).toInt(), 9);
 
     // Move the trash at the beginning of the list
@@ -420,17 +417,17 @@ void KFilePlacesModelTest::testDragAndDrop()
     QVERIFY(m_places->dropMimeData(mimeData, Qt::MoveAction, 0, 0, QModelIndex()));
 
     urls.clear();
-    urls << "trash:/" << QDir::homePath() << "remote:/" << KDE_ROOT_PATH
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QStringLiteral("trash:/") << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH)
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
     QCOMPARE(spy_moved.count(), 1);
     args = spy_moved.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 8);
     QCOMPARE(args.at(2).toInt(), 8);
-    QCOMPARE(args.at(3).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(3).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(4).toInt(), 0);
 
     // Move the trash in the list (at its original place)
@@ -440,17 +437,17 @@ void KFilePlacesModelTest::testDragAndDrop()
     QVERIFY(m_places->dropMimeData(mimeData, Qt::MoveAction, 4, 0, QModelIndex()));
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
     QCOMPARE(spy_moved.count(), 1);
     args = spy_moved.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 0);
     QCOMPARE(args.at(2).toInt(), 0);
-    QCOMPARE(args.at(3).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(3).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(4).toInt(), 4);
 
     // Dropping on an item is not allowed
@@ -471,22 +468,21 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     QSignalSpy spy_removed(m_places, SIGNAL(rowsRemoved(QModelIndex,int,int)));
     QSignalSpy spy_changed(m_places, SIGNAL(dataChanged(QModelIndex,QModelIndex)));
 
-    m_places->addPlace("Foo", QUrl::fromLocalFile("/home/foo"));
+    m_places->addPlace(QStringLiteral("Foo"), QUrl::fromLocalFile(QStringLiteral("/home/foo")));
 
     QStringList urls;
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom" << "/home/foo";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign") << QStringLiteral("/home/foo");
 
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 9);
     QCOMPARE(args.at(2).toInt(), 9);
     QCOMPARE(spy_removed.count(), 0);
 
-    const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kfileplaces/bookmarks.xml";
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
+    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark before_trash = m_places->bookmarkForIndex(m_places->index(2, 0));
     KBookmark foo = m_places->bookmarkForIndex(m_places->index(9, 0));
@@ -495,72 +491,72 @@ void KFilePlacesModelTest::testPlacesLifecycle()
     bookmarkManager->emitChanged(root);
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "/home/foo"
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("/home/foo")
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 10);
     QCOMPARE(args.at(2).toInt(), 10);
 
-    m_places->editPlace(m_places->index(3, 0), "Foo", QUrl::fromLocalFile("/mnt/foo"));
+    m_places->editPlace(m_places->index(3, 0), QStringLiteral("Foo"), QUrl::fromLocalFile(QStringLiteral("/mnt/foo")));
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "/mnt/foo"
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("/mnt/foo")
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
     QCOMPARE(spy_changed.count(), 1);
     args = spy_changed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), m_places->index(3, 0));
-    QCOMPARE(args.at(1).value<QModelIndex>(), m_places->index(3, 0));
+    QCOMPARE(args.at(0).toModelIndex(), m_places->index(3, 0));
+    QCOMPARE(args.at(1).toModelIndex(), m_places->index(3, 0));
 
     foo = m_places->bookmarkForIndex(m_places->index(3, 0));
-    foo.setFullText("Bar");
+    foo.setFullText(QStringLiteral("Bar"));
     bookmarkManager->notifyCompleteChange(QString());
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "/mnt/foo"
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("/mnt/foo")
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 0);
     QCOMPARE(spy_changed.count(), 10);
     args = spy_changed[3];
-    QCOMPARE(args.at(0).value<QModelIndex>(), m_places->index(3, 0));
-    QCOMPARE(args.at(1).value<QModelIndex>(), m_places->index(3, 0));
+    QCOMPARE(args.at(0).toModelIndex(), m_places->index(3, 0));
+    QCOMPARE(args.at(1).toModelIndex(), m_places->index(3, 0));
     spy_changed.clear();
 
     m_places->removePlace(m_places->index(3, 0));
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
 
-    m_places->addPlace("Foo", QUrl::fromLocalFile("/home/foo"), QString(), QString(), m_places->index(1, 0));
+    m_places->addPlace(QStringLiteral("Foo"), QUrl::fromLocalFile(QStringLiteral("/home/foo")), QString(), QString(), m_places->index(1, 0));
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << "/home/foo" << KDE_ROOT_PATH
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral("/home/foo") << QStringLiteral(KDE_ROOT_PATH)
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
 
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 2);
     QCOMPARE(args.at(2).toInt(), 2);
     QCOMPARE(spy_removed.count(), 0);
@@ -574,36 +570,35 @@ void KFilePlacesModelTest::testDevicePlugging()
     QSignalSpy spy_inserted(m_places, SIGNAL(rowsInserted(QModelIndex,int,int)));
     QSignalSpy spy_removed(m_places, SIGNAL(rowsRemoved(QModelIndex,int,int)));
 
-    fakeManager()->call("unplug", "/org/kde/solid/fakehw/volume_part1_size_993284096");
+    fakeManager()->call(QStringLiteral("unplug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     QStringList urls;
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 6);
     QCOMPARE(args.at(2).toInt(), 6);
 
-    fakeManager()->call("plug", "/org/kde/solid/fakehw/volume_part1_size_993284096");
+    fakeManager()->call(QStringLiteral("plug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 6);
     QCOMPARE(args.at(2).toInt(), 6);
     QCOMPARE(spy_removed.count(), 0);
 
     // Move the device in the list, and check that it memorizes the position across plug/unplug
 
-    const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kfileplaces/bookmarks.xml";
-    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
+    KBookmarkManager *bookmarkManager = KBookmarkManager::managerForFile(bookmarksFile(), QStringLiteral("kfilePlaces"));
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark before_trash = m_places->bookmarkForIndex(m_places->index(2, 0));
     KBookmark device = root.first(); // The device we'll move is the 7th bookmark
@@ -615,42 +610,42 @@ void KFilePlacesModelTest::testDevicePlugging()
     bookmarkManager->emitChanged(root);
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "/media/XO-Y4"
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("/media/XO-Y4")
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 7);
     QCOMPARE(args.at(2).toInt(), 7);
 
-    fakeManager()->call("unplug", "/org/kde/solid/fakehw/volume_part1_size_993284096");
+    fakeManager()->call(QStringLiteral("unplug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH)
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 0);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
 
-    fakeManager()->call("plug", "/org/kde/solid/fakehw/volume_part1_size_993284096");
+    fakeManager()->call(QStringLiteral("plug"), "/org/kde/solid/fakehw/volume_part1_size_993284096");
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "/media/XO-Y4"
-         << "trash:/" << "/media/nfs" << "/foreign" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("/media/XO-Y4")
+         << QStringLiteral("trash:/") << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
     QCOMPARE(spy_removed.count(), 0);
@@ -663,17 +658,17 @@ void KFilePlacesModelTest::testDevicePlugging()
     bookmarkManager->emitChanged(root);
 
     urls.clear();
-    urls << QDir::homePath() << "remote:/" << KDE_ROOT_PATH << "trash:/"
-         << "/media/nfs" << "/foreign" << "/media/XO-Y4" << "/media/floppy0" << "/media/cdrom";
+    urls << QDir::homePath() << QStringLiteral("remote:/") << QStringLiteral(KDE_ROOT_PATH) << QStringLiteral("trash:/")
+         << QStringLiteral("/media/nfs") << QStringLiteral("/media/floppy0") << QStringLiteral("/media/XO-Y4") << QStringLiteral("/media/cdrom") << QStringLiteral("/foreign");
     CHECK_PLACES_URLS(urls);
     QCOMPARE(spy_inserted.count(), 1);
     args = spy_inserted.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 6);
     QCOMPARE(args.at(2).toInt(), 6);
     QCOMPARE(spy_removed.count(), 1);
     args = spy_removed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>(), QModelIndex());
+    QCOMPARE(args.at(0).toModelIndex(), QModelIndex());
     QCOMPARE(args.at(1).toInt(), 3);
     QCOMPARE(args.at(2).toInt(), 3);
 }
@@ -683,19 +678,19 @@ void KFilePlacesModelTest::testDeviceSetupTeardown()
     QList<QVariant> args;
     QSignalSpy spy_changed(m_places, SIGNAL(dataChanged(QModelIndex,QModelIndex)));
 
-    fakeDevice("/org/kde/solid/fakehw/volume_part1_size_993284096/StorageAccess")->call("teardown");
+    fakeDevice(QStringLiteral("/org/kde/solid/fakehw/volume_part1_size_993284096/StorageAccess"))->call(QStringLiteral("teardown"));
 
     QCOMPARE(spy_changed.count(), 1);
     args = spy_changed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>().row(), 6);
-    QCOMPARE(args.at(1).value<QModelIndex>().row(), 6);
+    QCOMPARE(args.at(0).toModelIndex().row(), 6);
+    QCOMPARE(args.at(1).toModelIndex().row(), 6);
 
-    fakeDevice("/org/kde/solid/fakehw/volume_part1_size_993284096/StorageAccess")->call("setup");
+    fakeDevice(QStringLiteral("/org/kde/solid/fakehw/volume_part1_size_993284096/StorageAccess"))->call(QStringLiteral("setup"));
 
     QCOMPARE(spy_changed.count(), 1);
     args = spy_changed.takeFirst();
-    QCOMPARE(args.at(0).value<QModelIndex>().row(), 6);
-    QCOMPARE(args.at(1).value<QModelIndex>().row(), 6);
+    QCOMPARE(args.at(0).toModelIndex().row(), 6);
+    QCOMPARE(args.at(1).toModelIndex().row(), 6);
 }
 
 QTEST_MAIN(KFilePlacesModelTest)
